========
Overview
========

SAMMI (Shared Attribute and Metadata Management Interface) is a python package that provides a schema for metadata attributes within space weather data products.
This package is a SWxSOC project and can be used in conjunction with other SWxSOC projects, or as a standalone package. 

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs| |readthedocs|
    * - build status
      - |testing| |codestyle| |coverage|

.. |docs| image:: https://github.com/swxsoc/swxschema/actions/workflows/docs.yml/badge.svg
    :target: https://github.com/swxsoc/swxschema/actions/workflows/docs.yml
    :alt: Documentation Build Status

.. |testing| image:: https://github.com/swxsoc/swxschema/actions/workflows/testing.yml/badge.svg
    :target: https://github.com/swxsoc/swxschema/actions/workflows/testing.yml
    :alt: Build Status

.. |codestyle| image:: https://github.com/swxsoc/swxschema/actions/workflows/codestyle.yml/badge.svg
    :target: https://github.com/swxsoc/swxschema/actions/workflows/codestyle.yml
    :alt: Codestyle and linting using flake8

.. |coverage| image:: https://codecov.io/gh/swxsoc/swxschema/branch/main/graph/badge.svg?token=C6JLIWZRBU 
    :target: https://codecov.io/gh/swxsoc/swxschema
    :alt: Testing coverage

.. |readthedocs| image:: https://readthedocs.org/projects/swxschema/badge/?version=latest
    :target: https://swxschema.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. end-badges

Documentation
-------------
The documentation is hosted on readthedocs and is available `here <https://swxschema.readthedocs.io/en/latest/>`_.

License
-------

See the license/LICENSE file for more information.


Contributing
------------

We love contributions! This project is open source,
built on open source, and we'd love to have you hang out in our community.

**Imposter syndrome disclaimer**: We want your help. No, really.

There may be a little voice inside your head that is telling you that you're not
ready to be an open source contributor; that your skills aren't nearly good
enough to contribute. What could you possibly offer a project like this one?

We assure you - the little voice in your head is wrong. If you can write code at
all, you can contribute code to open source. Contributing to open source
projects is a fantastic way to advance one's coding skills. Writing perfect code
isn't the measure of a good developer (that would disqualify all of us!); it's
trying to create something, making mistakes, and learning from those
mistakes. That's how we all improve, and we are happy to help others learn.

Being an open source contributor doesn't just mean writing code, either. You can
help out by writing documentation, tests, or even giving feedback about the
project (and yes - that includes giving feedback about the contribution
process). Some of these contributions may be the most valuable to the project as
a whole, because you're coming to the project with fresh eyes, so you can see
the errors and assumptions that seasoned contributors have glossed over.

Note: This disclaimer was originally written by
`Adrienne Lowe <https://github.com/adriennefriend>`_ for a
`PyCon talk <https://www.youtube.com/watch?v=6Uj746j9Heo>`_, and was adapted by
by this project based on its use in the README file for the
`MetPy project <https://github.com/Unidata/MetPy>`_.

Code of Conduct
---------------
When you are interacting with the SWxSOC community you are asked to follow
our `Code of Conduct <https://github.com/swxsoc/code-of-conduct/blob/main/CODE_OF_CONDUCT.md>`_.

Acknowledgements
----------------
The package template used by this package is based on the one developed by the
`OpenAstronomy community <https://openastronomy.org>`_ and the `SunPy Project <https://sunpy.org/>`_.

Public Domain
-------------

This project constitutes a work of the United States Government and is not subject to domestic copyright protection under `17 USC § 105 <https://www.govinfo.gov/app/details/USCODE-2010-title17/USCODE-2010-title17-chap1-sec105>`__. Additionally, we waive copyright and related rights in the work worldwide through the `CC0 1.0 Universal public domain dedication <https://creativecommons.org/publicdomain/zero/1.0/>`__.

All contributions to this project will be released under the CC0
dedication. By submitting a pull request, you are agreeing to comply
with this waiver of copyright interest.
